<?php 



class LinkedIn_Example {

	public function __construct() {
		if ( $_SERVER["REQUEST_METHOD"] == "GET" && isset($_GET['code'])){
			
			require_once('../../../wp-config.php');
			require_once(ABSPATH . 'wp-includes/plugin.php');
			require_once(ABSPATH . 'wp-includes/pluggable.php');
			require_once(ABSPATH . 'wp-includes/general-template.php');
			
			$redirect = get_template_directory_uri() . '/linkedin.php';							
			$api_key = get_option( 'LINKEDIN_API_KEY' );
			$api_secret = get_option( 'LINKEDIN_API_SECRET_KEY' );			

			$args = array(
				'method' => 'POST',
				'httpversion' => '1.1',
				'blocking' => true,
				'body' => array( 
					'grant_type' => 'authorization_code',
					'code' => $_GET['code'],
					'redirect_uri' => $redirect,
					'client_id' => $api_key,
					'client_secret' => $api_secret
				)
			);

			add_filter('https_ssl_verify', '__return_false');
			$response = wp_remote_post( 'https://www.linkedin.com/uas/oauth2/accessToken', $args );
				
			$keys = json_decode($response['body']);
			
			if($keys) {
				update_option( 'LINKEDIN_AUTHENTICATION_TOKEN', $keys->{'access_token'} );
			}			
			wp_redirect( get_bloginfo( 'url' ) . '/wp-admin/options-general.php?page=linkedin.php' ); 
			exit; 
		}
		
		add_shortcode('linkedin', array($this, 'render_shortcode'));
		add_action('admin_menu', array($this, 'add_linkedin_admin_menu'));
		add_action('wp_footer', array($this, 'enqueue_linkedin_style'));		
	}
	
	public function add_linkedin_admin_menu() {  	
		add_options_page('LinkedIn Options', 'LinkedIn', 'manage_options', 'linkedin.php', array($this, 'add_linkedin_admin_page'));
		add_action( 'admin_print_scripts', array($this, 'enqueue_linkedin_style'));
	}  
	
	public function add_linkedin_admin_page() {
		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}
		
		if ( $_SERVER["REQUEST_METHOD"] == "POST" ){			
			update_option( 'LINKEDIN_API_KEY', $_POST['api_key'] );
			update_option( 'LINKEDIN_API_SECRET_KEY', $_POST['api_secret_key'] );			
		}
		
		?>
		<div class="linkedin-admin-options">
			<h1>Linked In Options</h1>
			<form name="options" method="POST" action="<?php echo $_SERVER['REQUEST_URI']; ?>">
				<label for="api_key">API Key<span class="required">(*)</span>: </label>
				<input type="text" name="api_key" value="<?php echo get_option( 'LINKEDIN_API_KEY', '' ); ?>" size="70">
				<br />
				<label for="api_secret_key">Consumer Secret<span class="required">(*)</span>: </label>
				<input type="text" name="api_secret_key" value="<?php echo get_option( 'LINKEDIN_API_SECRET_KEY', '' ); ?>" size="70">	
				<br />				
				<label for="bearer_token">Authentication Token: </label>
				<input type="text" disabled value="<?php echo get_option( 'LINKEDIN_AUTHENTICATION_TOKEN', '' ); ?>" size="70">
				<br />
				<input class="button-primary" type="submit" name="save" />
				
				<?php
			
				$state = base64_encode(time());
				$redirect = get_template_directory_uri() . '/linkedin.php';							
				$api_key = get_option( 'LINKEDIN_API_KEY' );
				$api_secret = get_option( 'LINKEDIN_API_SECRET_KEY' );
				$token = get_option( 'LINKEDIN_AUTHENTICATION_TOKEN' );
				
				if($api_key && $api_secret && !$token) {
					$api_url = "https://www.linkedin.com/uas/oauth2/authorization?response_type=code&client_id=$api_key&scope=r_fullprofile&state=$state&redirect_uri=$redirect";
					?>
					<a class="button-primary" type="button" href="<?php echo $api_url; ?>">Authenticate</a>
					<?php
				}
				
				?>
				<br/>
				<small>You can sign up for a API key <a href="https://developer.linkedin.com/" target="_blank">here</a></small>				
			</form>
			<br />
			<?php echo do_shortcode('[linkedin]'); ?>
		</div>
		<?php
	}
	
	public function render_shortcode($atts) {
		$return = '';
		
		extract( shortcode_atts( array(
			'id' => 'linkedin-1',
		), $atts ) );
		
		$token = get_option( 'LINKEDIN_AUTHENTICATION_TOKEN' );
		
		if($token) {
			add_filter('https_ssl_verify', '__return_false');
			$api_url = "https://api.linkedin.com/v1/people/~:(id,first-name,last-name,headline,industry,summary,positions,picture-url,skills,languages,educations,recommendations-received)?oauth2_access_token=$token&format=json";
			
			$response = wp_remote_get( $api_url );
			
			$json = json_decode( $response['body'] );
			
			$return .= '<section class="shortcuts">';
			$return .= '<h2><a href="#shortcuts">Quick links</a></h2>';
			$return .= '<ul>';
			$return .= '<li><a href="#skills">Skills</a></li>';
			$return .= '<li><a href="#summary">Summary</a></li>';
			$return .= '<li><a href="#positions">Positions</a></li>';
			$return .= '<li><a href="#recommendations">Recommendations</a></li>';
			$return .= '</ul>';
			$return .= '</section>';
			
			$return .= '<section class="about">';
			$return .= '<h2>' . $json->{'firstName'} . ' ' . $json->{'lastName'} . '</h2>';
			$return .= '<p>' . $json->{'headline'} . '</p>';
			$return .= '</section>';
			
			$skills = $json->{'skills'}->{'values'};
			$first = true;
			$return .= '<section class="skills">';
			$return .= '<h2><a href="#" name="skills">Skills</a></h2>';
			$return .= '<pre style="font-size: smaller;">';
			foreach($skills as $i => $skill) {
				$return .= ( $first == false ? ', ' : '') . $skill->{'skill'}->{'name'};
				$first = false;
			}
			$return .= '</pre>';
			$return .= '<h2><a href="#" name="summary">Summary</a></h2>';
			$return .= '<pre>' . $json->{'summary'} . '</pre>';
			$return .= '</section>';
			
			$jobs = $json->{'positions'}->{'values'};
			$return .= '<section class="positions">';
			$return .= '<h2><a href="#" name="positions">Positions - ' . $json->{'industry'} . '</a></h2>';
			$return .= '<p>';
			
			foreach($jobs as $i => $job) {
				$return .= '<h2>' . $job->{'title'} . '</h2>';
				$return .= '<h3>' . $job->{'company'}->{'name'};
				$return .= ' ( ' . $job->{'startDate'}->{'year'} . ' - ';
				if($job->{'isCurrent'} == "true"){
					$return .= 'Current';
				} else {
					$return .= $job->{'endDate'}->{'year'};
				}
				$return .= ' )</h3>';
				$return .= '<pre>' . $job->{'summary'} . '</pre>';

			}

			$return .= '</p>';
			$return .= '</section>';
			
			$recommendations = $json->{'recommendationsReceived'}->{'values'};
			$return .= '<section class="recommendations">';
			$return .= '<h2><a href="#" name="recommendations">Recommendations</a></h2>';
			foreach($recommendations as $i => $recommendation) {
				$recommendedBy = $recommendation->{'recommender'};
				$return .= '<h3>' . $recommendedBy->{'firstName'} . ' ' . $recommendedBy->{'lastName'} . '</h3>';
				$return .= '<blockquote>';
				$return .= $recommendation->{'recommendationText'};				
				$return .= '</blockquote>';				
			}
			$return .= '</section>';

			return $return;
		}
	}
	
	public function enqueue_linkedin_style() {
		$token = get_option( 'LINKEDIN_AUTHENTICATION_TOKEN' );

		if($token) {
			 wp_register_style( 'linkedin-style', get_template_directory_uri() . '/linkedin.css');

			 wp_enqueue_style( 'linkedin-style' );
		}
	}
}

$linkedIn = new LinkedIn_Example();

?>